==> apache-shardingsphere-5.5.1-src.zip: apache-shardingsphere-5.5.1-src-release/test/it/rewriter/src/test/java/org/apache/shardingsphere/test/it/rewrite/engine/parameter/SQLRewriteEngineTestParameters.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.test.it.rewrite.engine.parameter;

import lombok.Getter;
import lombok.RequiredArgsConstructor;

import java.util.List;

/**
 * Test parameters for SQL rewrite engine.
 */
@RequiredArgsConstructor
@Getter
public final class SQLRewriteEngineTestParameters {
    
    private final String type;
    
    private final String name;
    
    private final String fileName;
    
    private final String ruleFile;
    
    private final String inputSQL;
    
    private final List<Object> inputParameters;
    
    private final List<String> outputSQLs;
    
    private final List<List<Object>> outputGroupedParameters;
    
    private final String databaseType;
    
    @Override
    public String toString() {
        return String.format("{%s}: {%s} ({%s}) -> {%s}", type, name, databaseType, fileName);
    }
}

==> apache-shardingsphere-5.5.2-src.zip: apache-shardingsphere-5.5.2-src-release/test/it/rewriter/src/test/java/org/apache/shardingsphere/test/it/rewrite/engine/parameter/SQLRewriteEngineTestParameters.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.test.it.rewrite.engine.parameter;

import lombok.Getter;
import lombok.RequiredArgsConstructor;
import org.apache.shardingsphere.test.it.rewrite.engine.type.SQLExecuteType;

import java.util.List;

/**
 * Test parameters for SQL rewrite engine.
 */
@RequiredArgsConstructor
@Getter
public final class SQLRewriteEngineTestParameters {
    
    private final String type;
    
    private final String name;
    
    private final String fileName;
    
    private final String ruleFile;
    
    private final String inputSQL;
    
    private final List<Object> inputParameters;
    
    private final List<String> outputSQLs;
    
    private final List<List<Object>> outputGroupedParameters;
    
    private final String databaseType;
    
    private final SQLExecuteType sqlExecuteType;
    
    @Override
    public String toString() {
        return String.format("{%s}: {%s} ({%s}) -> {%s}", type + "/" + sqlExecuteType, name, databaseType, fileName);
    }
}
